Title: Welcome to Journal Generator
Date: 2020-06-11

Hi! And welcome to Journal Generator. This is a generator for static websites, but not any special website, a *Journal* or *blog* as the internauts would say. In a site like this you write your thoughts, things you want to share or show to the world, even maybe a tutorial for something you created and want other people to use. Who knows?

Posts in **Journal Generator** are written in [Markdown](https://en.wikipedia.org/wiki/Markdown). From here on out I'll show you what can you write with this syntax.

You can have lists:

* Item 1
* Item 2
    * Item 2.1
    * Item 2.2
        * Item 2.2.1
* Item 3


```python
# You can also have code snippets
def main():
    print("This is a snippet!")
    
if __name__ == '__main__':
    main()
```

You also can use images like this:

![guanaco](/static/guanaco.jpg)
*This is a [Guanaco](https://en.wikipedia.org/wiki/Guanaco)*

When using captions, remember to NOT leave a blank line between the image and the emphasis element. Also, like we did in the caption you can have [links](https://en.wikipedia.org/wiki/Guanaco) to other places on the web.

If you want a more extensive guide on how to write posts using Markdown, please go to [this reference page](https://help.github.com/en/github/writing-on-github/basic-writing-and-formatting-syntax)

